@@ -2,17 +2,18 @@ import urllib.request as request
 from urllib.parse import urlparse
 import os
 import uuid
-from notion2md import console
-from notion2md.config_store import get_config
+
+from notion2md.console.formatter import *
+from notion2md.config import Config
+
+from clikit.api.io import IO
 
 # Since external file block cannot guarantees
 # whether the file is downloadable or not,
 # there is no external file downloader
-def downloader(url:str) -> str:
+def downloader(url:str,cfg:Config,io:IO) -> str:
     file_name = os.path.basename(urlparse(url).path)
-    cfg = get_config()
-
-    if cfg.download:
+    if cfg.download and io:
         if file_name:
             name,ext = os.path.splitext(file_name)
 
@@ -20,13 +21,13 @@ def downloader(url:str) -> str:
             fullpath = os.path.join(cfg.output_path,downloaded_file_name)
                 
             try:
-                console.print_status("Downloading",f"{file_name}")
+                io.write_line(status("Downloading",f"{file_name}"))
                 request.urlretrieve(url,fullpath)
-                console.print_status("Downloaded",f'successfully downloaded "{file_name}" -> "{downloaded_file_name}"')
+                io.write_line(status("Downloaded",f'successfully downloaded "{file_name}" -> "{downloaded_file_name}"'))
                 return name,downloaded_file_name
-            except:
-                console.print_error(f"cannot download {file_name}")
+            except Exception as e:
+                io.write_line(error(f"cannot download {file_name}: {e}"))
         else:
-            console.print_error(f"unvalid {url}")
+            io.write_line(error(f"unvalid {url}"))
     else:
         return file_name,url
